@@ -1,5 +1,5 @@
 import requests
-from typing import Optional
+from typing import Optional, List
 from bs4 import BeautifulSoup
 import logging
 
@@ -31,6 +31,32 @@ def _parse_comic_page(html: str) -> Optional[str]:
     return None
 
 
+def _gocomics_request(url) -> requests.models.Response:
+    req = requests.get(
+        url,
+        allow_redirects=False,
+    )
+
+    assert req.status_code == 200
+    return req
+
+
+def fetch_calendar(comic: str, datestr: str) -> List[str]:
+    """
+    Fetch a list of days with comics in a given month
+
+    Arguments:
+    comic -- URL slug of the comic, can be copied from gocomics URLs.
+    datestr -- Year and month of the requested calendar. Format is YYYY/MM or YYYY-MM.
+    """
+    url = "https://www.gocomics.com/calendar/{}/{}".format(
+        comic, datestr.replace("-", "/")
+    )
+    req = _gocomics_request(url)
+
+    return req.json()
+
+
 def fetch_url(comic: str, datestr: str) -> Optional[str]:
     """
     Fetch image URL for a given date of a comic from gocomics.com
@@ -40,16 +66,6 @@ def fetch_url(comic: str, datestr: str) -> Optional[str]:
     datestr -- Date of the requested comic. Format is YYYY/MM/DD or YYYY-MM-DD.
     """
     url = "https://www.gocomics.com/{}/{}".format(comic, datestr.replace("-", "/"))
-    req = requests.get(
-        url,
-        allow_redirects=False,
-    )
-
-    if req.status_code != 200:
-        # TODO: This isn't ideal.
-        logging.error(
-            "Got {} when trying to fetch {}: {}".format(req.status_code, url, req.text)
-        )
-        return None
+    req = _gocomics_request(url)
 
     return _parse_comic_page(req.text)
